@@ -1,24 +1,24 @@
 /*****************************************************************************
  * sdt.c: SDT decoder/generator
  *----------------------------------------------------------------------------
- * (c)2001-2002 VideoLAN
- * $Id: sdt.c 187 2009-11-18 07:26:10Z md $
+ * Copyright (C) 2001-2010 VideoLAN
+ * $Id$
  *
  * Authors: Johan Bilien <jobi@via.ecp.fr>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *----------------------------------------------------------------------------
  *
@@ -58,7 +58,6 @@ int dvbpsi_AttachSDT(dvbpsi_decoder_t * p_psi_decoder, uint8_t i_table_id,
   dvbpsi_demux_t* p_demux = (dvbpsi_demux_t*)p_psi_decoder->p_private_decoder;
   dvbpsi_demux_subdec_t* p_subdec;
   dvbpsi_sdt_decoder_t*  p_sdt_decoder;
-  unsigned int i;
 
   if(dvbpsi_demuxGetSubDec(p_demux, i_table_id, i_extension))
   {
@@ -100,7 +99,7 @@ int dvbpsi_AttachSDT(dvbpsi_decoder_t * p_psi_decoder, uint8_t i_table_id,
   /* SDT decoder initial state */
   p_sdt_decoder->b_current_valid = 0;
   p_sdt_decoder->p_building_sdt = NULL;
-  for(i = 0; i <= 255; i++)
+  for(unsigned int i = 0; i <= 255; i++)
     p_sdt_decoder->ap_sections[i] = NULL;
 
   return 0;
@@ -119,8 +118,6 @@ void dvbpsi_DetachSDT(dvbpsi_demux_t * p_demux, uint8_t i_table_id,
   dvbpsi_demux_subdec_t** pp_prev_subdec;
   dvbpsi_sdt_decoder_t* p_sdt_decoder;
 
-  unsigned int i;
-
   p_subdec = dvbpsi_demuxGetSubDec(p_demux, i_table_id, i_extension);
 
   if(p_demux == NULL)
@@ -136,7 +133,7 @@ void dvbpsi_DetachSDT(dvbpsi_demux_t * p_demux, uint8_t i_table_id,
 
   free(p_sdt_decoder->p_building_sdt);
 
-  for(i = 0; i <= 255; i++)
+  for(unsigned int i = 0; i <= 255; i++)
   {
     if(p_sdt_decoder->ap_sections[i])
       dvbpsi_DeletePSISections(p_sdt_decoder->ap_sections[i]);
@@ -277,7 +274,6 @@ void dvbpsi_GatherSDTSections(dvbpsi_decoder_t * p_psi_decoder,
                         = (dvbpsi_sdt_decoder_t*)p_private_decoder;
   int b_append = 1;
   int b_reinit = 0;
-  unsigned int i;
 
   DVBPSI_DEBUG_ARG("SDT decoder",
                    "Table version %2d, " "i_table_id %2d, " "i_extension %5d, "
@@ -362,7 +358,7 @@ void dvbpsi_GatherSDTSections(dvbpsi_decoder_t * p_psi_decoder,
       p_sdt_decoder->p_building_sdt = NULL;
     }
     /* Clear the section array */
-    for(i = 0; i <= 255; i++)
+    for(unsigned int i = 0; i <= 255; i++)
     {
       if(p_sdt_decoder->ap_sections[i] != NULL)
       {
@@ -402,7 +398,7 @@ void dvbpsi_GatherSDTSections(dvbpsi_decoder_t * p_psi_decoder,
 
     /* Check if we have all the sections */
     b_complete = 0;
-    for(i = 0; i <= p_sdt_decoder->i_last_section_number; i++)
+    for(unsigned int i = 0; i <= p_sdt_decoder->i_last_section_number; i++)
     {
       if(!p_sdt_decoder->ap_sections[i])
         break;
@@ -419,7 +415,7 @@ void dvbpsi_GatherSDTSections(dvbpsi_decoder_t * p_psi_decoder,
       /* Chain the sections */
       if(p_sdt_decoder->i_last_section_number)
       {
-        for(i = 0; (int)i <= p_sdt_decoder->i_last_section_number - 1; i++)
+        for(unsigned int i = 0; (int)i <= p_sdt_decoder->i_last_section_number - 1; i++)
           p_sdt_decoder->ap_sections[i]->p_next =
                                         p_sdt_decoder->ap_sections[i + 1];
       }
@@ -433,7 +429,7 @@ void dvbpsi_GatherSDTSections(dvbpsi_decoder_t * p_psi_decoder,
                                  p_sdt_decoder->p_building_sdt);
       /* Reinitialize the structures */
       p_sdt_decoder->p_building_sdt = NULL;
-      for(i = 0; i <= p_sdt_decoder->i_last_section_number; i++)
+      for(unsigned int i = 0; i <= p_sdt_decoder->i_last_section_number; i++)
         p_sdt_decoder->ap_sections[i] = NULL;
     }
   }
@@ -499,7 +495,7 @@ dvbpsi_psi_section_t *dvbpsi_GenSDTSections(dvbpsi_sdt_t* p_sdt)
   dvbpsi_psi_section_t * p_result = dvbpsi_NewPSISection(1024);
   dvbpsi_psi_section_t * p_current = p_result;
   dvbpsi_psi_section_t * p_prev;
- 
+
   dvbpsi_sdt_service_t *    p_service = p_sdt->p_first_service;
 
   p_current->i_table_id = 0x42;
@@ -517,16 +513,16 @@ dvbpsi_psi_section_t *dvbpsi_GenSDTSections(dvbpsi_sdt_t* p_sdt)
   p_current->p_data[8] = (p_sdt->i_network_id >> 8) ;
   p_current->p_data[9] = p_sdt->i_network_id;
   p_current->p_data[10] = 0xff;
-  
+
   /* SDT service */
   while(p_service != NULL)
   {
     uint8_t * p_service_start = p_current->p_payload_end;
-    
+
     uint16_t i_service_length = 5;
 
     dvbpsi_descriptor_t * p_descriptor = p_service->p_first_descriptor;
-    
+
     while ( (p_descriptor != NULL)&& ((p_service_start - p_current->p_data) + i_service_length <= 1020) )
     {
       i_service_length += p_descriptor->i_length + 2;
@@ -557,7 +553,7 @@ dvbpsi_psi_section_t *dvbpsi_GenSDTSections(dvbpsi_sdt_t* p_sdt)
       p_current->p_data[8] = (p_sdt->i_network_id >> 8) ;
       p_current->p_data[9] = p_sdt->i_network_id;
       p_current->p_data[10] = 0xff;
-      
+
       p_service_start = p_current->p_payload_end;
     }
 
@@ -593,7 +589,7 @@ dvbpsi_psi_section_t *dvbpsi_GenSDTSections(dvbpsi_sdt_t* p_sdt)
     p_service_start[4] = i_service_length;
 
     p_service = p_service->p_next;
-  }    
+  }
 
   /* Finalization */
   p_prev = p_result;
